@@ -15,7 +15,7 @@ pascal_per_millibar = 100
 seconds_in_hour = 3600
 fillvalue_double = 9.969209968386869e+36
 fillvalue_float = 9.96921e+36
-jaws_version = '0.4.8'
+jaws_version = '0.5'
 
 ###############################################################################
 
@@ -32,7 +32,8 @@ def load_dataframe(name, input_file, header_rows, **kwargs):
 	global columns
 
 	if (name == 'gcnet' and header_rows == 54) or (name == 'promice' and len(input_file_vars) == 44) or (
-		name == 'aaws' and len(input_file_vars) == 6)	or (name == 'imau/ant') or (name == 'imau/grl'):
+		name == 'aaws' and len(input_file_vars) == 6)	or (name == 'imau/ant') or (name == 'imau/grl') or (
+		name=='scar'):
 
 		path = relative_path('resources/{}/columns.txt'.format(name))
 		with open(path) as stream:
@@ -105,21 +106,31 @@ def get_encoding(name, fillvalue, comp_level):
 	return data
 
 
-def load_dataset_attributes(name, ds, args):
+def load_dataset_attributes(name, ds, args, **kwargs):
 	path = 'resources/{}/ds.json'.format(name)
 	attr_dict = read_ordered_json(path)
 
 	ds.attrs = attr_dict.pop('attributes')
+
+	if name == 'scar':
+		country = kwargs.pop('country')
+		institution = kwargs.pop('institution')
+
+		if country:
+			ds.attrs['operated_by'] = country
+		if institution:
+			ds.attrs['institution'] = institution
+
 	ds.attrs['history'] = '{} {}'.format(datetime.now(), ' '.join(sys.argv))
 	ds.attrs['JAWS'] = 'Justified Automatic Weather Station software version {} (Homepage = http://github.com/jaws/jaws)'.format(jaws_version)
 
 	derived_vars = ['time', 'time_bounds', 'sza', 'station_name', 'latitude', 'longitude', 'surface_temp', 
-	'ice_velocity_GPS_total', 'ice_velocity_GPS_x', 'ice_velocity_GPS_y']
+	'ice_velocity_GPS_total', 'ice_velocity_GPS_x', 'ice_velocity_GPS_y', 'height']
 
 	no_drv_tm_vars = []
 	
 	if not args.no_drv_tm:
-		no_drv_tm_vars = ['hour', 'month', 'day']
+		no_drv_tm_vars = ['hour', 'month', 'day', 'day_of_year']
 
 	for key, value in attr_dict.items():
 		for key1, value1 in value.items():
